/*
 * Copyright 2012 Smallcrew, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.smallcrew.security.domain;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.web.authentication.rememberme.PersistentRememberMeToken;
import org.springframework.security.web.authentication.rememberme.PersistentTokenRepository;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;

@Repository
@Transactional
public class UserTokenService implements PersistentTokenRepository {
  @Autowired
  private UserTokenRepository userTokenRepository;

  @Override
  public void createNewToken(PersistentRememberMeToken token) {
    UserToken userToken = new UserToken();
    userToken.setDate(token.getDate());
    userToken.setSeries(token.getSeries());
    userToken.setTokenValue(token.getTokenValue());
    userToken.setUsername(token.getUsername());
    userTokenRepository.save(userToken);
  }

  @Override
  public void updateToken(String series, String tokenValue, Date lastUsed) {
    UserToken token = userTokenRepository.findBySeries(series);
    token.setSeries(series);
    token.setTokenValue(tokenValue);
    token.setDate(lastUsed);
    userTokenRepository.save(token);
  }

  @Override
  public PersistentRememberMeToken getTokenForSeries(String seriesId) {
    UserToken token = userTokenRepository.findBySeries(seriesId);
    PersistentRememberMeToken t = null;
    if (token != null) {
      t = new PersistentRememberMeToken(token.getUsername(), token.getSeries(), token.getTokenValue(), token.getDate());
    }
    return t;
  }

  @Override
  public void removeUserTokens(String username) {
    List<UserToken> userTokens = userTokenRepository.findByUsername(username);
    for (UserToken userToken : userTokens) {
      userTokenRepository.delete(userToken);
    }
  }
}
